@@ -202,7 +202,7 @@ Ancillary::read_ancillary_das( DAS &das,
         das.parse( in ) ;
         int res = fclose( in ) ;
         if( res )
-            DBG(cerr << "DODSFilter::read_ancillary_das - Failed to close file " << (void *)in << endl) ;
+            DBG(cerr << "Ancillary::read_ancillary_das - Failed to close file " << (void *)in << endl) ;
     }
 }
 
@@ -219,7 +219,7 @@ Ancillary::read_ancillary_dds( DDS &dds,
         dds.parse( in ) ;
         int res = fclose( in ) ;
         if( res )
-            DBG(cerr << "DODSFilter::read_ancillary_das - Failed to close file " << (void *)in << endl) ;
+            DBG(cerr << "Ancillary::read_ancillary_das - Failed to close file " << (void *)in << endl) ;
     }
 }
 
