@@ -49,6 +49,8 @@
 #include "ConstraintEvaluator.h"
 #endif
 
+#define FILE_METHODS 1
+
 namespace libdap
 {
 
@@ -99,10 +101,10 @@ public:
 
     virtual bool set_value(const dods_byte value);
     virtual dods_byte value() const;
-    //#if FILE_METHODS
+#if FILE_METHODS
     virtual void print_val(FILE *out, string space = "",
                            bool print_decl_p = true);
-    //#endif
+#endif
     virtual void print_val(ostream &out, string space = "",
                            bool print_decl_p = true);
 
