@@ -25,7 +25,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: ConstraintEvaluator.cc 23555 2010-09-14 16:43:59Z jimg $"
+    {"$Id: ConstraintEvaluator.cc 24370 2011-03-28 16:21:32Z jimg $"
     };
 
 #include "ConstraintEvaluator.h"
@@ -351,8 +351,10 @@ ConstraintEvaluator::eval_function_clauses(DDS &dds)
 	    result->set_send_p(true);
 	    fdds->add_var(result);
 	}
-	else
+	else {
+		delete fdds;
 	    throw Error("A function was called but failed to return a value.");
+	}
     }
 
     return fdds;
@@ -380,8 +382,10 @@ ConstraintEvaluator::eval_function_clauses(DataDDS &dds)
 	    result->set_send_p(true);
 	    fdds->add_var(result);
 	}
-	else
+	else {
+		delete fdds;
 	    throw Error("A function was called but failed to return a value.");
+	}
     }
 
     return fdds;
