@@ -38,12 +38,25 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: Float64.cc 19948 2008-12-03 23:51:12Z jimg $"
+    {"$Id: Float64.cc 21699 2009-11-05 00:06:01Z jimg $"
     };
 
 #include <iomanip>
 
+#include "Byte.h"
+#include "Int16.h"
+#include "UInt16.h"
+#include "Int32.h"
+#include "UInt32.h"
+#include "Float32.h"
 #include "Float64.h"
+#include "Str.h"
+#include "Url.h"
+#include "Array.h"
+#include "Structure.h"
+#include "Sequence.h"
+#include "Grid.h"
+
 #include "DDS.h"
 #include "util.h"
 #include "parser.h"
@@ -190,7 +203,8 @@ Float64::set_value(dods_float64 val)
 
     return true;
 }
-//#if FILE_METHODS
+
+#if FILE_METHODS
 void
 Float64::print_val(FILE *out, string space, bool print_decl_p)
 {
@@ -204,7 +218,8 @@ Float64::print_val(FILE *out, string space, bool print_decl_p)
     else
         fprintf(out, "%.15g", _buf) ;
 }
-//#endif
+#endif
+
 void
 Float64::print_val(ostream &out, string space, bool print_decl_p)
 {
