@@ -29,7 +29,7 @@
 #include "config.h"
 
 static char id[] not_used =
-    { "$Id: GridGeoConstraint.cc 23447 2010-08-27 19:38:04Z jimg $"
+    { "$Id: GridGeoConstraint.cc 24281 2011-03-09 00:22:31Z jimg $"
     };
 
 #include <cmath>
@@ -55,11 +55,9 @@ namespace libdap {
 
 /** @brief Initialize GeoConstraint with a Grid.
 
-    @todo Remove ds_name. 10/2/08
     @param grid Set the GeoConstraint to use this Grid variable. It is the
     caller's responsibility to ensure that the value \e grid is a valid Grid
     variable.
-    @param ds_name The name of the dataset. Passed to BaseType::read().
  */
 GridGeoConstraint::GridGeoConstraint(Grid *grid)
         : GeoConstraint(), d_grid(grid), d_latitude(0), d_longitude(0)
