@@ -59,6 +59,9 @@ using std::vector;
 namespace libdap
 {
 
+extern int www_trace;
+extern int dods_keep_temps;
+
 /** Use the CURL library to dereference a HTTP URL. Scan the response for
     headers used by the DAP 2.0 and extract their values. The body of the
     response is made available by a FILE pointer.
@@ -136,8 +139,8 @@ public:
     void set_accept_deflate(bool defalte);
     void set_xdap_protocol(int major, int minor);
 
-    /** Set the cookie jar. THis function sets the name of a file used to store 
-    cookies returned by servers. This will help with things like single 
+    /** Set the cookie jar. This function sets the name of a file used to store
+    cookies returned by servers. This will help with things like single
     sign on systems.
 
     @param cookie_jar The pathname to the file that stores cookies. If this
@@ -148,7 +151,7 @@ public:
     }
 
     /** Set the state of the HTTP cache. By default, the HTTP cache is
-    enabled of disabled using the value of the \c USE_CACHE property in
+    enabled or disabled using the value of the \c USE_CACHE property in
     the \c .dodsrc file. Use this method to set the state from within a
     program.
     @param enabled True to use the cache, False to disable. */
@@ -167,9 +170,6 @@ public:
     HTTPResponse *fetch_url(const string &url);
 };
 
-ObjectType get_type(const string &value); // deprecated
-ObjectType get_description_type(const string &value);
-
 } // namespace libdap
 
 #endif // _httpconnect_h
