@@ -39,10 +39,13 @@
 
 #include "GNURegex.h"  // GNU Regex class used for string =~ op.
 #include "parser.h"  // for ID_MAX
-#include "ce_expr.tab.h"
+#include "ce_expr.tab.hh"
 
 using namespace std;
 
+namespace libdap
+{
+
 inline unsigned
 dods_max(int i1, int i2)
 {
@@ -268,4 +271,6 @@ bool rops(T1 a, T2 b, int op)
     }
 }
 
+} // namespace libdap
+
 #endif // _operators_h
