@@ -32,6 +32,8 @@
 #include "Error.h"
 #endif
 
+namespace libdap
+{
 
 /** SignalHandlerRegisteredErr is thrown by HTTPCache::instance() if a signal
     handler is already registered.
@@ -56,4 +58,6 @@ public:
     }
 };
 
+} // namespace libdap
+
 #endif // _signal_handler_registered_err_h
