@@ -37,10 +37,24 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: Str.cc 20518 2009-03-05 23:39:46Z jimg $"
+    {"$Id: Str.cc 21699 2009-11-05 00:06:01Z jimg $"
     };
 
+#include "Byte.h"
+#include "Int16.h"
+#include "UInt16.h"
+#include "Int32.h"
+#include "UInt32.h"
+#include "Float32.h"
+#include "Float64.h"
 #include "Str.h"
+#include "Url.h"
+#include "Array.h"
+#include "Structure.h"
+#include "Sequence.h"
+#include "Grid.h"
+
+
 #include "DDS.h"
 #include "util.h"
 #include "parser.h"
@@ -222,7 +236,8 @@ Str::value() const
 {
     return _buf;
 }
-//#if FILE_METHODS
+
+#if FILE_METHODS
 void
 Str::print_val(FILE *out, string space, bool print_decl_p)
 {
@@ -233,7 +248,8 @@ Str::print_val(FILE *out, string space, bool print_decl_p)
     else
         fprintf(out, "\"%s\"", escattr(_buf).c_str()) ;
 }
-//#endif
+#endif
+
 void
 Str::print_val(ostream &out, string space, bool print_decl_p)
 {
@@ -259,7 +275,7 @@ Str::ops(BaseType *b, int op)
     }
 
     // Extract the second arg's value.
-    if (!b || !b->read_p() && !b->read()) {
+    if (!b || !(b->read_p() || b->read())) {
         // Jose Garcia
         // Since the read method is virtual and implemented outside
         // libdap++ if we cannot read the data that is the problem
