@@ -41,6 +41,8 @@
 #include "dods-limits.h"
 #include "BaseType.h"
 
+#define FILE_METHODS 1
+
 namespace libdap
 {
 
@@ -93,10 +95,10 @@ public:
 
     virtual bool set_value(const string &value);
     virtual string value() const;
-    //#if FILE_METHODS
+#if FILE_METHODS
     virtual void print_val(FILE *out, string space = "",
                            bool print_decl_p = true);
-    //#endif
+#endif
     virtual void print_val(ostream &out, string space = "",
                            bool print_decl_p = true);
 
