@@ -46,12 +46,24 @@ namespace libdap {
     created.
 
 */
-
 Url::Url(const string &n) : Str(n)
 {
     set_type(dods_url_c);  // override the type set by Str
 }
 
+/** The URL server-side constructor requires the name of the variable
+    to be created and the name of the dataset from which this variable is
+    being created.
+
+    @param n A string containing the name of the variable to be created.
+    @param d A string containing the name of the dataset from which this
+    variable is being created.
+*/
+Url::Url(const string &n, const string &d) : Str(n, d)
+{
+    set_type(dods_url_c);  // override the type set by Str
+}
+
 BaseType *
 Url::ptr_duplicate()
 {
