@@ -86,10 +86,21 @@ private:
     vector<string> d_str;       // special storage for strings. jhrg 2/11/05
     vector<BaseType *> _vec; // array for other data
 
+    // the number of elements we have allocated memory to store.
+    // This should be either the sizeof(buf)/width() for cardinal data
+    // or the capacity of d_str for strings or capacity of _vec.
+    unsigned int _capacity;
+
 protected:
     // This function copies the private members of Vector.
     void _duplicate(const Vector &v);
 
+    bool is_cardinal_type() const;
+    unsigned int create_cardinal_data_buffer_for_type(unsigned int numEltsOfType);
+    void delete_cardinal_data_buffer();
+
+    template <class CardType> void set_cardinal_values_internal(const CardType* fromArray, int numElts);
+
 public:
     Vector(const string &n, BaseType *v, const Type &t);
     Vector(const string &n, const string &d, BaseType *v, const Type &t);
@@ -100,6 +111,8 @@ public:
     Vector &operator=(const Vector &rhs);
     virtual BaseType *ptr_duplicate() = 0;
 
+    virtual void set_name(const std::string& name);
+
     virtual int element_count(bool leaves);
 
     virtual void set_send_p(bool state);
@@ -124,6 +137,15 @@ public:
 
     void vec_resize(int l);
 
+    void clear_local_data();
+
+    virtual unsigned int get_value_capacity() const;
+    virtual void reserve_value_capacity(unsigned int numElements);
+    virtual void reserve_value_capacity();
+
+    virtual unsigned int set_value_slice_from_row_major_vector
+      (const Vector& rowMajorData, unsigned int startElement);
+
     virtual bool set_value(dods_byte *val, int sz);
     virtual bool set_value(vector<dods_byte> &val, int sz);
     virtual bool set_value(dods_int16 *val, int sz);
