@@ -32,7 +32,20 @@
 
 #include "XDRFileMarshaller.h"
 
-#include "Vector.h"
+#include "Byte.h"
+#include "Int16.h"
+#include "UInt16.h"
+#include "Int32.h"
+#include "UInt32.h"
+#include "Float32.h"
+#include "Float64.h"
+#include "Str.h"
+#include "Url.h"
+#include "Array.h"
+#include "Structure.h"
+#include "Sequence.h"
+#include "Grid.h"
+
 #include "util.h"
 #include "InternalErr.h"
 
@@ -88,13 +101,6 @@ XDRFileMarshaller::put_int16( dods_int16 val )
 void
 XDRFileMarshaller::put_int32( dods_int32 val )
 {
-#if 0
-#ifdef _MSC_VER
-    if( !XDR_INT32( _sink, (int *)&val ) )
-#else
-    if( !XDR_INT32( _sink, &val ) )
-#endif
-#endif
     if( !XDR_INT32( _sink, &val ) )
         throw Error("Network I/O Error. Could not read int 32 data.\nThis may be due to a bug in libdap, on the server or a\nproblem with the network connection.");
 }
@@ -123,13 +129,6 @@ XDRFileMarshaller::put_uint16( dods_uint16 val )
 void
 XDRFileMarshaller::put_uint32( dods_uint32 val )
 {
-#if 0
-#ifdef _MSC_VER
-    if( !XDR_UINT32( _sink, (unsigned int *)&val ) )
-#else
-  	if( !XDR_UINT32( _sink, &val ) )
-#endif
-#endif
     if( !XDR_UINT32( _sink, &val ) )
         throw Error("Network I/O Error. Could not send uint 32 data. This may be due to a\nbug in libdap or a problem with the network connection.");
 }
