@@ -32,7 +32,22 @@
 
 #include "XDRFileUnMarshaller.h"
 
+#include "Byte.h"
+#include "Int16.h"
+#include "UInt16.h"
+#include "Int32.h"
+#include "UInt32.h"
+#include "Float32.h"
+#include "Float64.h"
+#include "Str.h"
+#include "Url.h"
+#include "Array.h"
+#include "Structure.h"
+#include "Sequence.h"
+#include "Grid.h"
+#if  0
 #include "Vector.h"
+#endif
 #include "util.h"
 #include "InternalErr.h"
 
@@ -88,13 +103,6 @@ XDRFileUnMarshaller::get_int16( dods_int16 &val )
 void
 XDRFileUnMarshaller::get_int32( dods_int32 &val )
 {
-#if 0
-#ifdef _MSC_VER
-    if( !XDR_INT32( _source, (int *)&val ) )
-#else
-	if( !XDR_INT32( _source, &val ) )
-#endif
-#endif
     if( !XDR_INT32( _source, &val ) )
         throw Error("Network I/O Error. Could not read int 32 data. This may be due to a\nbug in libdap or a problem with the network connection.");
 }
@@ -123,13 +131,6 @@ XDRFileUnMarshaller::get_uint16( dods_uint16 &val )
 void
 XDRFileUnMarshaller::get_uint32( dods_uint32 &val )
 {
-#if 0
-#ifdef _MSC_VER
-    if( !XDR_UINT32( _source, (unsigned int *)&val ) )
-#else
-	if( !XDR_UINT32( _source, &val ) )
-#endif
-#endif
     if( !XDR_UINT32( _source, &val ) )
         throw Error("Network I/O Error. Could not read uint 32 data. This may be due to a\nbug in libdap or a problem with the network connection.");
 }
