@@ -36,7 +36,7 @@
 #include "config.h"
 
 static char rcsid[]not_used =
-{   "$Id: ce_functions.cc 23551 2010-09-13 21:00:46Z jimg $"
+{   "$Id: ce_functions.cc 24370 2011-03-28 16:21:32Z jimg $"
 };
 
 #include <limits.h>
@@ -49,6 +49,8 @@ static char rcsid[]not_used =
 #include <algorithm>
 
 //#define DODS_DEBUG
+#undef FUNCTION_DAP	// undef so the dap() function always returns an error;
+			// use keywords instead.
 
 #include "BaseType.h"
 #include "Byte.h"
@@ -130,6 +132,7 @@ string extract_string_argument(BaseType * arg)
 
     return s;
 }
+
 template<class T> static void set_array_using_double_helper(Array * a,
         double *src, int src_len)
 {
@@ -153,7 +156,7 @@ template<class T> static void set_array_using_double_helper(Array * a,
  source (\e src) array is different than the destination (\e dest) the
  caller has made a mistake. In that case it will throw an Error object.
 
- After setting that values, this method sets the \c read_p property for
+ After setting the values, this method sets the \c read_p property for
  \e dest.
 
  @param dest An Array. The values are written to this array, reusing
@@ -319,7 +322,11 @@ double extract_double_value(BaseType * arg)
 }
 
 /** This server-side function returns version information for the server-side
- functions. */
+ functions. Note that this function takes no arguments and returns a
+ String using the BaseType value/result parameter.
+
+ @param btpp A pointer to the return value; caller must delete.
+*/
 void
 function_version(int, BaseType *[], DDS &, BaseType **btpp)
 {
@@ -331,6 +338,7 @@ function_version(int, BaseType *[], DDS &, BaseType **btpp)
                        <function name=\"grid\" version=\"1.0\"/>\
                        <function name=\"linear_scale\" version=\"1.0b1\"/>\
                        <function name=\"version\" version=\"1.0\"/>\
+        	       <function name=\"dap\" version=\"1.0\"/>\
                      </functions>";
 
     //                        <function name=\"geoarray\" version=\"0.9b1\"/>
@@ -342,6 +350,23 @@ function_version(int, BaseType *[], DDS &, BaseType **btpp)
     return;
 }
 
+void
+function_dap(int, BaseType *[], DDS &, ConstraintEvaluator &)
+{
+#ifdef FUNCTION_DAP
+    if (argc != 1) {
+	throw Error("The 'dap' function must be called with a version number.\n\
+	see http://docs.opendap.org/index.php/Server_Side_Processing_Functions#dap");
+    }
+
+    double pv = extract_double_value(argv[0]);
+    dds.set_dap_version(pv);
+#else
+    throw Error("The 'dap' function is not supported in lieu of Constraint expression 'keywords.'\n\
+see http://docs.opendap.org/index.php/Server_Side_Processing_Functions#keywords");
+#endif
+}
+
 static void parse_gse_expression(gse_arg * arg, BaseType * expr)
 {
     gse_restart(0); // Restart the scanner.
@@ -435,8 +460,8 @@ static void apply_grid_selection_expressions(Grid * grid,
  @param argv An array of BaseType pointers which hold the arguments to be
  passed to geogrid. The arguments may be Strings, Integers, or Reals, subject
  to the above constraints.
- @param dds The DDS which holds the Grid.
- @param dataset Name of the dataset.
+ @param btpp A pointer to the return value; caller must delete.
+
  @see geogrid() (func_geogrid_select) A function which has logic specific
  to longitude/latitude selection. */
 void
@@ -460,12 +485,15 @@ function_grid(int argc, BaseType * argv[], DDS &, BaseType **btpp)
     if (!original_grid)
         throw Error(malformed_expr,"The first argument to grid() must be a Grid variable!");
 
-    // Duplicate the grid; DODSFilter::send_data() will delete the variable
+    // Duplicate the grid; ResponseBuilder::send_data() will delete the variable
     // after serializing it.
-    Grid *l_grid = dynamic_cast < Grid * >(original_grid->ptr_duplicate());
-    if (!l_grid)
+    BaseType *btp = original_grid->ptr_duplicate();
+    Grid *l_grid = dynamic_cast < Grid * >(btp);
+    if (!l_grid) {
+    	delete btp;
         throw InternalErr(__FILE__, __LINE__, "Expected a Grid.");
-
+    }
+    
     DBG(cerr << "grid: past initialization code" << endl);
 
     // Read the maps. Do this before calling parse_gse_expression(). Avoid
@@ -537,9 +565,8 @@ function_grid(int argc, BaseType * argv[], DDS &, BaseType **btpp)
  @param argv An array of BaseType pointers which hold the arguments to be
  passed to geogrid. The arguments may be Strings, Integers, or Reals,
  subject to the above constraints.
- @param dds The DDS which holds the Grid. This DDS \e must include
- attributes.
- @param dataset Name of the dataset.
+ @param btpp A pointer to the return value; caller must delete.
+
  @return The constrained and read Grid, ready to be sent. */
 void
 function_geogrid(int argc, BaseType * argv[], DDS &, BaseType **btpp)
@@ -773,10 +800,10 @@ static double get_missing_value(BaseType *var)
  constants 'm' and 'b' or the function will look for the COARDS attributes
  'scale_factor' and 'add_offset'.
 
- @param argc
- @param argv
- @param dds
- @param dataset
+ @param argc A count of the arguments 
+ @param argv An array of pointers to each argument, wrapped in a child of BaseType
+ @param btpp A pointer to the return value; caller must delete.
+
  @return The scaled variable, represented using Float64
  @exception Error Thrown if scale_factor is not given and the COARDS
  attributes cannot be found OR if the source variable is not a
@@ -927,10 +954,11 @@ function_linear_scale(int argc, BaseType * argv[], DDS &, BaseType **btpp)
 
  @note Only the plat-carre projection and wgs84 datum are currently
  supported.
- @param argc
- @param argv
- @param dds
- @param dataset
+
+ @param argc A count of the arguments 
+ @param argv An array of pointers to each argument, wrapped in a child of BaseType
+ @param btpp A pointer to the return value; caller must delete.
+
  @return The Array, constrained by the selection
  @exception Error Thrown if thins go awry. */
 void
@@ -1036,6 +1064,8 @@ void register_functions(ConstraintEvaluator & ce)
     ce.add_function("geoarray", function_geoarray);
 #endif
     ce.add_function("version", function_version);
+
+    ce.add_function("dap", function_dap);
 }
 
 } // namespace libdap
