@@ -1,3 +1,6 @@
+namespace libdap
+{
+
 struct ce_parser_arg
 {
     ConstraintEvaluator *eval;
@@ -29,3 +32,5 @@ struct ce_parser_arg
     }
 };
 
+} // namespace libdap
+
