@@ -176,6 +176,8 @@ string
 id2www_ce(string in, const string &allowable)
 {
     return id2www(in, allowable);
+
+
 }
 
 /** Given a string that contains WWW escape sequences, translate those escape
@@ -185,7 +187,7 @@ id2www_ce(string in, const string &allowable)
     -Places in the dap code where www2id() is called:
      -# Array::append_dim() the name is decoded before it is added
      -# AttrTable::set_name(), AttrTable::append_attr(),
-        AttrTable::append_container(), AttrTable?::del_attr(),
+        AttrTable::append_container(), AttrTable::del_attr(),
         AttrTable::add_container_alias(), AttrTable::add_value_alias()
         names are decoded before that are set/used.
      -# BaseType::set_name() Names are decoded before they are set
@@ -196,10 +198,12 @@ id2www_ce(string in, const string &allowable)
      -# Grid::var(), Sequence::var(), Structure::var() Variable names are decoded.
 
    -In the server code:
-     -# DODSFilter::initialize() The dataset name is decoded except that %20
+     -# ResponseBuilder::initialize() The dataset name is decoded except that %20
         is not removed.
-     -# DODSFilter::set_ce() The CE is decoded, except for spaces (%20).
-     -# DODSFilter::set_dataset_name() same logic as the first case.
+     -# ResponseBuilder::set_ce() The CE is decoded, except for spaces (%20).
+     -# ResponseBuilder::set_dataset_name() same logic as the first case.
+     -# The ResponseBuilder methods supersede methods with the same names
+        from DODSFilter, which is still in the code although deprecated.
 
     @param in The string to modify.
     @param escape The character used to signal the beginning of an escape
