@@ -36,7 +36,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    { "$Id: getdap.cc 19917 2008-11-25 23:47:56Z jimg $"
+    { "$Id: getdap.cc 21695 2009-11-04 17:45:04Z jimg $"
     };
 
 #ifdef WIN32
@@ -50,7 +50,8 @@ static char rcsid[] not_used =
 
 #include "GetOpt.h"
 
-#include "AISConnect.h"
+#include "Sequence.h"
+#include "Connect.h"
 #include "Response.h"
 #include "StdinResponse.h"
 
@@ -63,6 +64,7 @@ using namespace libdap ;
 const char *version = CVER " (" DVR " DAP/" DAP_PROTOCOL_VERSION ")";
 
 extern int libdap::dods_keep_temps;     // defined in HTTPResponse.h
+extern int libdap::www_trace;
 
 void usage(string name)
 {
@@ -98,24 +100,24 @@ void usage(string name)
     cerr << "        i: For each URL, get the server version." << endl;
     cerr << "        d: For each URL, get the the DDS." << endl;
     cerr << "        a: For each URL, get the the DAS." << endl;
-    cerr << "        A: Use the AIS for DAS objects." << endl;
     cerr << "        D: For each URL, get the the DataDDS." << endl;
     cerr <<
     "        x: For each URL, get the DDX object. Does not get data."
     << endl;
-    cerr << "        X: Build a DDX in getdap using the DDS and DAS." << endl;
-    cerr << "        B: <AIS xml dataBase>. Overrides .dodsrc." << endl;
-    cerr << "        v: Verbose." << endl;
-    cerr << "        V: Version." << endl;
-    cerr << "        c: <expr> is a constraint expression. Used with -D." <<
+    cerr << "        X: Request a DataDDX from the server (the DAP4 data response" << endl;
+    cerr << "        B: Build a DDX in getdap using the DDS and DAS." << endl;
+    cerr << "        v: Verbose output." << endl;
+    cerr << "        V: Version of this client; see 'i' for server version." << endl;
+    cerr << "        c: <expr> is a constraint expression. Used with -D/X." <<
     endl;
     cerr << "           NB: You can use a `?' for the CE also." << endl;
-    cerr << "        k: Keep temporary files created by libdap core" << endl;
+    cerr << "        k: Keep temporary files created by libdap." << endl;
     cerr << "        m: Request the same URL <num> times." << endl;
     cerr << "        z: Ask the server to compress data." << endl;
     cerr << "        s: Print Sequences using numbered rows." << endl;
     cerr << "        M: Assume data read from a file has no MIME headers" << endl;
     cerr << "           (the default is to assume the headers are present)." << endl;
+    cerr << "        p: Set DAP protocol to x.y" << endl;
 }
 
 bool read_data(FILE * fp)
@@ -151,13 +153,14 @@ static void print_data(DDS & dds, bool print_rows = false)
 
 int main(int argc, char *argv[])
 {
-    GetOpt getopt(argc, argv, "idaDxXAVvkB:c:m:zshM?Hp:");
+    GetOpt getopt(argc, argv, "idaDxXBVvkc:m:zshM?Hp:t");
     int option_char;
 
     bool get_das = false;
     bool get_dds = false;
     bool get_data = false;
     bool get_ddx = false;
+    bool get_data_ddx = false;
     bool build_ddx = false;
     bool get_version = false;
     bool cexpr = false;
@@ -165,13 +168,11 @@ int main(int argc, char *argv[])
     bool multi = false;
     bool accept_deflate = false;
     bool print_rows = false;
-    bool use_ais = false;
     bool mime_headers = true;
     int times = 1;
     int dap_client_major = 2;
     int dap_client_minor = 0;
     string expr = "";
-    string ais_db = "";
 
 #ifdef WIN32
     _setmode(_fileno(stdout), _O_BINARY);
@@ -192,10 +193,7 @@ int main(int argc, char *argv[])
             get_ddx = true;
             break;
         case 'X':
-            build_ddx = true;
-            break;
-        case 'A':
-            use_ais = true;
+            get_data_ddx = true;
             break;
         case 'V':
             fprintf(stderr, "getdap version: %s\n", version);
@@ -218,8 +216,7 @@ int main(int argc, char *argv[])
             times = atoi(getopt.optarg);
             break;
         case 'B':
-            use_ais = true;
-            ais_db = getopt.optarg;
+            build_ddx = true;
             break;
         case 'z':
             accept_deflate = true;
@@ -238,6 +235,9 @@ int main(int argc, char *argv[])
             iss >> dap_client_minor;
             break;
         }
+        case 't':
+            www_trace = 1;
+            break;
         case 'h':
         case '?':
         default:
@@ -255,15 +255,8 @@ int main(int argc, char *argv[])
 
             string name = argv[i];
             Connect *url = 0;
-            if (use_ais) {
-                if (!ais_db.empty())
-                    url = new AISConnect(name, ais_db);
-                else
-                    url = new AISConnect(name);
-            }
-            else {
-                url = new Connect(name);
-            }
+
+            url = new Connect(name);
 
             // This overrides the value set in the .dodsrc file.
             if (accept_deflate)
@@ -400,7 +393,7 @@ int main(int argc, char *argv[])
                         fprintf(stderr, "DDX:\n");
                     }
 
-                    dds.print_xml(cout, false, "getdap; no blob yet");
+                    dds.print_xml(cout, false);
                 }
             }
 
@@ -427,7 +420,7 @@ int main(int argc, char *argv[])
                         fprintf(stderr, "Client-built DDX:\n");
                     }
 
-                    dds.print_xml(cout, false, "getdap; no blob yet");
+                    dds.print_xml(cout, false);
                 }
             }
 
@@ -456,6 +449,31 @@ int main(int argc, char *argv[])
                 }
             }
 
+            else if (get_data_ddx) {
+                for (int j = 0; j < times; ++j) {
+                    BaseTypeFactory factory;
+                    DataDDS dds(&factory);
+                    try {
+                        DBG(cerr << "URL: " << url->URL(false) << endl);
+                        DBG(cerr << "CE: " << expr << endl);
+                        url->request_data_ddx(dds, expr);
+
+                        if (verbose)
+                            fprintf(stderr, "DAP version: %s, Server version: %s\n",
+                                    url->get_protocol().c_str(),
+                                    url->get_version().c_str());
+
+                        print_data(dds, print_rows);
+                    }
+                    catch (Error & e) {
+                        cerr << e.get_error_message() << endl;
+                        delete url;
+                        url = 0;
+                        continue;
+                    }
+                }
+            }
+
             else {
                 // if (!get_das && !get_dds && !get_data) This code uses
                 // HTTPConnect::fetch_url which cannot be accessed using an
