@@ -39,7 +39,7 @@
 #undef FILE_METHODS
 
 static char rcsid[] not_used =
-    {"$Id: mime_util.cc 22703 2010-05-11 18:10:01Z jimg $"
+    {"$Id: mime_util.cc 24370 2011-03-28 16:21:32Z jimg $"
     };
 
 #include <cstring>
@@ -83,115 +83,27 @@ static char rcsid[] not_used =
 #endif
 
 // ...not using a const string here to avoid global objects. jhrg 12/23/05
-#define CRLF "\r\n"             // Change here, expr-test.cc and DODSFilter.cc
+#define CRLF "\r\n"             // Change here, expr-test.cc, in DODSFilter and ResponseBuilder
 
 using namespace std;
 
 namespace libdap {
 
-static const int TimLen = 26; // length of string from asctime()
-static const int CLUMP_SIZE = 1024; // size of clumps to new in fmakeword()
-
-/** This sends a formatted block of text to the client, containing
-    version information about various aspects of the server.  The
-    arguments allow you to enclose version information about the
-    filter program and the dataset in the message.  Either argument
-    (or both) may be omitted, in which case no script or dataset
-    version information will be printed.
-
-    @brief Send a version number.
-    @param script_ver The version of the filter script executing this
-    function.
-    @param dataset_ver The version of the dataset.
-    @return TRUE for success. Always returns true.
-*/
-bool
-do_version(const string &script_ver, const string &dataset_ver)
+/** Get the last modified time. Assume <tt>name</tt> is a file and
+    find its last modified time. If <tt>name</tt> is not a file, then
+    return now as the last modified time.
+    @param name The name of a file.
+    @return The last modified time or the current time. */
+time_t
+last_modified_time(const string &name)
 {
-    fprintf(stdout, "HTTP/1.0 200 OK%s", CRLF) ;
-    fprintf(stdout, "XDODS-Server: %s%s", DVR, CRLF) ;
-    fprintf(stdout, "XOPeNDAP-Server: %s%s", DVR, CRLF) ;
-    fprintf(stdout, "XDAP: %s%s", DAP_PROTOCOL_VERSION, CRLF) ;
-    fprintf(stdout, "Content-Type: text/plain%s", CRLF) ;
-    fprintf(stdout, CRLF) ;
+    struct stat m;
 
-    fprintf(stdout, "Core software version: %s%s", DVR, CRLF) ;
-
-    if (script_ver != "")
-        fprintf(stdout, "Server Script Revision: %s%s", script_ver.c_str(), CRLF) ;
-
-    if (dataset_ver != "")
-        fprintf(stdout,  "Dataset version: %s%s", dataset_ver.c_str(), CRLF) ;
-
-    fflush(stdout) ;            // Not sure this is needed. jhrg 12/23/05
-
-    return true;
-}
-
-/** Prints an error message in the <tt>httpd</tt> system log file, along with
-    a time stamp and the client host name (or address).
-
-    Use this instead of the functions in liberrmsg.a in the programs run by
-    the CGIs to report errors so those errors show up in HTTPD's log files.
-
-    @brief Logs an error message.
-    @return void
-*/
-void
-ErrMsgT(const string &Msgt)
-{
-    time_t TimBin;
-    char TimStr[TimLen];
-
-    if (time(&TimBin) == (time_t) - 1)
-        strncpy(TimStr, "time() error           ", TimLen-1);
-    else {
-        strncpy(TimStr, ctime(&TimBin), TimLen-1);
-        TimStr[TimLen - 2] = '\0'; // overwrite the \n
-    }
-
-    cerr << "[" << TimStr << "] DAP server error: " << Msgt << endl;
-}
-
-// Given a pathname, return just the filename component with any extension
-// removed. The new string resides in newly allocated memory; the caller must
-// delete it when done using the filename.
-// Originally from the netcdf distribution (ver 2.3.2).
-//
-// *** Change to string class argument and return type. jhrg
-// *** Changed so it also removes the#path#of#the#file# from decompressed
-//     files.  rph.
-// Returns: A filename, with path and extension information removed. If
-// memory for the new name cannot be allocated, does not return!
-
-/** Given a pathname, this function returns just the file name
-    component of the path.  That is, given <tt>/a/b/c/ralph.nc.das</tt>, it
-    returns <tt>ralph.nc</tt>.
-
-    @brief Returns the filename portion of a pathname.
-    @param path A C-style simple string containing a pathname to be
-    parsed.
-    @return A C-style simple string containing the filename component
-    of the given pathname.
-*/
-string
-name_path(const string &path)
-{
-    if (path == "")
-        return string("");
-
-    string::size_type delim = path.find_last_of(FILE_DELIMITER);
-    string::size_type pound = path.find_last_of("#");
-    string new_path;
-
-    if (pound != string::npos)
-        new_path = path.substr(pound + 1);
+    if (stat(name.c_str(), &m) == 0 && (S_IFREG & m.st_mode))
+        return m.st_mtime;
     else
-        new_path = path.substr(delim + 1);
-
-    return new_path;
+        return time(0);
 }
-
 // Return a MIME rfc-822 date. The grammar for this is:
 //       date-time   =  [ day "," ] date time        ; dd mm yy
 //                                                   ;  hh:mm:ss zzz
@@ -257,20 +169,108 @@ rfc822_date(const time_t t)
     return string(d);
 }
 
-/** Get the last modified time. Assume <tt>name</tt> is a file and
-    find its last modified time. If <tt>name</tt> is not a file, then
-    return now as the last modified time.
-    @param name The name of a file.
-    @return The last modified time or the current time. */
-time_t
-last_modified_time(const string &name)
-{
-    struct stat m;
+static const int TimLen = 26; // length of string from asctime()
+static const int CLUMP_SIZE = 1024; // size of clumps to new in fmakeword()
 
-    if (stat(name.c_str(), &m) == 0 && (S_IFREG & m.st_mode))
-        return m.st_mtime;
+/** This sends a formatted block of text to the client, containing
+    version information about various aspects of the server.  The
+    arguments allow you to enclose version information about the
+    filter program and the dataset in the message.  Either argument
+    (or both) may be omitted, in which case no script or dataset
+    version information will be printed.
+
+    @brief Send a version number.
+    @param script_ver The version of the filter script executing this
+    function.
+    @param dataset_ver The version of the dataset.
+    @return TRUE for success. Always returns true.
+*/
+bool
+do_version(const string &script_ver, const string &dataset_ver)
+{
+    fprintf(stdout, "HTTP/1.0 200 OK%s", CRLF) ;
+    fprintf(stdout, "XDODS-Server: %s%s", DVR, CRLF) ;
+    fprintf(stdout, "XOPeNDAP-Server: %s%s", DVR, CRLF) ;
+    fprintf(stdout, "XDAP: %s%s", DAP_PROTOCOL_VERSION, CRLF) ;
+    fprintf(stdout, "Content-Type: text/plain%s", CRLF) ;
+    fprintf(stdout, CRLF) ;
+
+    fprintf(stdout, "Core software version: %s%s", DVR, CRLF) ;
+
+    if (script_ver != "")
+        fprintf(stdout, "Server Script Revision: %s%s", script_ver.c_str(), CRLF) ;
+
+    if (dataset_ver != "")
+        fprintf(stdout,  "Dataset version: %s%s", dataset_ver.c_str(), CRLF) ;
+
+    fflush(stdout) ;            // Not sure this is needed. jhrg 12/23/05
+
+    return true;
+}
+
+/** Prints an error message in the <tt>httpd</tt> system log file, along with
+    a time stamp and the client host name (or address).
+
+    Use this instead of the functions in liberrmsg.a in the programs run by
+    the CGIs to report errors so those errors show up in HTTPD's log files.
+
+    @deprecated
+    @brief Logs an error message.
+    @return void
+*/
+void
+ErrMsgT(const string &Msgt)
+{
+    time_t TimBin;
+    char TimStr[TimLen];
+
+    if (time(&TimBin) == (time_t) - 1)
+        strncpy(TimStr, "time() error           ", TimLen-1);
+    else {
+        strncpy(TimStr, ctime(&TimBin), TimLen-1);
+        TimStr[TimLen - 2] = '\0'; // overwrite the \n
+    }
+
+    cerr << "[" << TimStr << "] DAP server error: " << Msgt << endl;
+}
+
+// Given a pathname, return just the filename component with any extension
+// removed. The new string resides in newly allocated memory; the caller must
+// delete it when done using the filename.
+// Originally from the netcdf distribution (ver 2.3.2).
+//
+// *** Change to string class argument and return type. jhrg
+// *** Changed so it also removes the#path#of#the#file# from decompressed
+//     files.  rph.
+// Returns: A filename, with path and extension information removed. If
+// memory for the new name cannot be allocated, does not return!
+
+/** Given a pathname, this function returns just the file name
+    component of the path.  That is, given <tt>/a/b/c/ralph.nc.das</tt>, it
+    returns <tt>ralph.nc</tt>.
+
+    @brief Returns the filename portion of a pathname.
+    @param path A C-style simple string containing a pathname to be
+    parsed.
+    @return A C-style simple string containing the filename component
+    of the given pathname.
+*/
+string
+name_path(const string &path)
+{
+    if (path == "")
+        return string("");
+
+    string::size_type delim = path.find_last_of(FILE_DELIMITER);
+    string::size_type pound = path.find_last_of("#");
+    string new_path;
+
+    if (pound != string::npos)
+        new_path = path.substr(pound + 1);
     else
-        return time(0);
+        new_path = path.substr(delim + 1);
+
+    return new_path;
 }
 
 // Send string to set the transfer (mime) type and server version
@@ -296,7 +296,7 @@ static const char *encoding[] =
     Modified to include tests for the descriptions that use hyphens in addition
     to underscores. 8/1/08 jhrg
 
-    @deprecated Use get_description_type instead */
+    @deprecated  */
 ObjectType
 get_type(const string &value)
 {
@@ -362,6 +362,7 @@ get_description_type(const string &value)
 /** Generate an HTTP 1.0 response header for a text document. This is used
     when returning a serialized DAS or DDS object.
 
+    @deprecated
     @param out Write the MIME header to this FILE pointer.
     @param type The type of this this response. Defaults to
     application/octet-stream.
@@ -416,6 +417,7 @@ set_mime_text(FILE *out, ObjectType type, const string &ver,
 /** Generate an HTTP 1.0 response header for a text document. This is used
     when returning a serialized DAS or DDS object.
 
+    @deprecated
     @param strm Write the MIME header to this stream.
     @param type The type of this this response. Defaults to
     application/octet-stream.
@@ -469,6 +471,7 @@ set_mime_text(ostream &strm, ObjectType type, const string &ver,
 #if FILE_METHODS
 /** Generate an HTTP 1.0 response header for a html document.
 
+    @deprecated
     @param out Write the MIME header to this FILE pointer.
     @param type The type of this this response.
     @param ver The version string; denotes the libdap implementation
@@ -516,6 +519,7 @@ set_mime_html(FILE *out, ObjectType type, const string &ver,
 
 /** Generate an HTTP 1.0 response header for a html document.
 
+    @deprecated
     @param strm Write the MIME header to this stream.
     @param type The type of this this response.
     @param ver The version string; denotes the libdap implementation
@@ -564,6 +568,7 @@ set_mime_html(ostream &strm, ObjectType type, const string &ver,
 /** Write an HTTP 1.0 response header for our binary response document (i.e.,
     the DataDDS object).
 
+    @deprecated
     @param out Write the MIME header to this FILE pointer.
     @param type The type of this this response. Defaults to
     application/octet-stream.
@@ -610,6 +615,7 @@ set_mime_binary(FILE *out, ObjectType type, const string &ver,
 /** Write an HTTP 1.0 response header for our binary response document (i.e.,
     the DataDDS object).
 
+    @deprecated
     @param strm Write the MIME header to this stream.
     @param type The type of this this response. Defaults to
     application/octet-stream.
@@ -721,6 +727,7 @@ const size_t line_length = 1024;
     separator lines that use either a CRLF pair (the correct line ending) or
     just a newline (a common error).
 
+    @deprecated
     @param in Read from this stream (FILE *)
     @return A string that contains the next header line or is empty indicating
     the separator has been read.
@@ -772,6 +779,10 @@ void parse_mime_header(const string &header, string &name, string &value)
 }
 
 /** Is this string the same as the MPM boundary value?
+
+    @note Since fgets() is used to read into line, it is guaranteed to be
+    null terminated.
+
     @param line The input to test
     @param boundary The complete boundary line to test for, excluding
     terminating characters.
@@ -780,18 +791,19 @@ void parse_mime_header(const string &header, string &name, string &value)
 
 bool is_boundary(const char *line, const string &boundary)
 {
-    if (!(line[0] == '-' && line[1] == '-'))
-	return false;
-    else {
-	return strncmp(line, boundary.c_str(), boundary.length()) == 0;
-    }
+    if (strlen(line) < 2 || !(line[0] == '-' && line[1] == '-'))
+		return false;
+    else
+		return strncmp(line, boundary.c_str(), boundary.length()) == 0;
 }
 
 /** Read the next line of input and test to see if it is a multipart MIME
     boundary line. If the value of boundary is the default (an empty string)
     then just test that the line starts with "--". In either case, return the
     value of boundary just read.
+
     @param boundary Value of the boundary to look for - optional
+    @param in Read from this FILE*
     @return The value of teh boundary header read
     @exception Error if no boundary was found.
  */
@@ -823,7 +835,7 @@ string read_multipart_boundary(FILE *in, const string &boundary)
     @param content_type The expected value of the Content-Type header
     @param object_type The expected value of the Content-Description header
     @param cid The expected value of the Content-Id header - optional.
-    @param boundary The expected value of the boundary - optional
+
     @return The value of the MIME boundary
     @exception Error if the boundary is not found or if any of the expected
     header values don't match. The optional values are tested only if they
@@ -865,6 +877,7 @@ void read_multipart_headers(FILE *in, const string &content_type,
 /** Given a Content-Id read from the DDX, return the value to look for in a
     MPM Content-Id header. This function downcases the CID to match the value
     returned by parse_mime_header.
+
     @param cid The Content-Id read from the DDX
     @return The header value to look for.
     @exception Error if the CID does not start with the string "cid:"
@@ -885,6 +898,8 @@ string cid_to_header_value(const string &cid)
 
 #if FILE_METHODS
 /** Generate an HTTP 1.0 response header for an Error object.
+
+    @deprecated
     @param out Write the MIME header to this FILE pointer.
     @param code HTTP 1.0 response code. Should be 400, ... 500, ...
     @param reason Reason string of the HTTP 1.0 response header.
@@ -913,6 +928,8 @@ set_mime_error(FILE *out, int code, const string &reason,
 #endif
 
 /** Generate an HTTP 1.0 response header for an Error object.
+
+    @deprecated
     @param strm Write the MIME header to this stream.
     @param code HTTP 1.0 response code. Should be 400, ... 500, ...
     @param reason Reason string of the HTTP 1.0 response header.
@@ -944,6 +961,7 @@ set_mime_error(ostream &strm, int code, const string &reason,
     conditional get has not been modified relative to the condition given in
     the request. This will have to be a date until the servers support ETags.
 
+    @deprecated
     @brief Send a `Not Modified' response.
     @param out Write the response to this FILE pointer. */
 void
@@ -960,6 +978,7 @@ set_mime_not_modified(FILE *out)
     conditional get has not been modified relative to the condition given in
     the request. This will have to be a date until the servers support ETags.
 
+    @deprecated
     @brief Send a `Not Modified' response.
     @param strm Write the response to this stream. */
 void
@@ -977,6 +996,7 @@ set_mime_not_modified(ostream &strm)
     are not checked to see if they are valid HTML (which they must
     be).
 
+    @deprecated
     @return True if the `override file' is present, false otherwise. in the
     later case <tt>doc</tt>'s contents are undefined.  */
 bool
@@ -1003,6 +1023,7 @@ found_override(string name, string &doc)
     If no MIME header is found, then the input stream is `emptied' and will
     contain nothing.
 
+    @deprecated
     @brief Read and discard the MIME header of the stream <tt>in</tt>.
     @return True if a MIME header is found, false otherwise.
 */
