@@ -11,18 +11,18 @@
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
- 
+
 // (c) COPYRIGHT URI/MIT 1995-1997,1999
 // Please read the full copyright statement in the file COPYRIGHT_URI.
 //
@@ -45,6 +45,8 @@ class TestArray: public Array, public TestCommon {
     bool d_series_values;
     void _duplicate(const TestArray &ts);
     int m_offset(int y, Dim_iter Y, int x);
+    unsigned int print_array(ostream &out, unsigned int index,
+			     unsigned int dims, unsigned int shape[]);
 
 public:
     TestArray(const string &n, BaseType *v);
@@ -59,9 +61,9 @@ public:
 
     virtual bool read();
     virtual bool name_is_special();
-    virtual void build_special_values();    
+    virtual void build_special_values();
     virtual void constrained_matrix(char *constrained_array);
-    
+
     virtual void output_values(std::ostream &out);
 
     void set_series_values(bool);
