@@ -47,6 +47,7 @@
 #endif
 
 #include "TestFloat32.h"
+#include "debug.h"
 
 extern int test_variable_sleep_interval;
 
@@ -68,6 +69,12 @@ TestFloat32::TestFloat32(const string &n) : Float32(n), d_series_values(false)
     _buf = 0.0;
 }
 
+TestFloat32::TestFloat32(const string &n, const string &d)
+    : Float32(n, d), d_series_values(false)
+{
+    _buf = 0.0;
+}
+
 TestFloat32::TestFloat32(const TestFloat32 &rhs) : Float32(rhs), TestCommon(rhs)
 {
     _duplicate(rhs);
@@ -99,8 +106,9 @@ TestFloat32::output_values(std::ostream &out)
 }
 
 bool
-TestFloat32::read(const string &)
+TestFloat32::read()
 {
+    DBG(cerr << "Entering TestFloat32::read for " << name() << endl);
     if (read_p())
 	return true;
 
@@ -110,6 +118,9 @@ TestFloat32::read(const string &)
     if (get_series_values()) {
         _buf += 10.0;
         _buf = (float)(trunc(10000 * sin(trunc(_buf))) / 100);
+	/*
+	_buf -= 0.11 ;
+	*/
     }
     else {
         _buf = (float)99.999;
@@ -117,5 +128,7 @@ TestFloat32::read(const string &)
     
     set_read_p(true);
 
+    DBG(cerr << "In TestFloat32::read, _buf = " << _buf << endl);
+    
     return true;
 }
