@@ -47,7 +47,8 @@ class TestFloat64: public Float64, public TestCommon {
     void _duplicate(const TestFloat64 &ts);
 
 public:
-    TestFloat64(const string &n = "");
+    TestFloat64(const string &n);
+    TestFloat64(const string &n, const string &d);
     TestFloat64(const TestFloat64 &rhs);
 
     virtual ~TestFloat64() {}
@@ -56,7 +57,7 @@ public:
 
     virtual BaseType *ptr_duplicate();
     
-    virtual bool read(const string &dataset);
+    virtual bool read();
     
     virtual void output_values(std::ostream &out);
 
