@@ -63,7 +63,7 @@ TestGrid::output_values(std::ostream &out)
     bool pyg = projection_yields_grid();
     if (pyg)
         out << "{  Array: " ;
-    else if (components(true) > 1)
+    else //if (components(true) > 1)
         out << "{ " ;
 
     if (array_var()->send_p()) {
@@ -99,7 +99,7 @@ TestGrid::output_values(std::ostream &out)
         }
     }
 
-    if (pyg || components(true) > 1) 
+    //if (pyg || components(true) > 1)
         out << " }" ;
 }
 
