@@ -38,7 +38,7 @@
 #define DODS_DEBUG
 
 static char rcsid[] not_used =
-    { "$Id: expr-test.cc 23477 2010-09-02 21:02:59Z jimg $" };
+    { "$Id: expr-test.cc 24082 2011-02-08 18:44:27Z jimg $" };
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -62,7 +62,10 @@ static char rcsid[] not_used =
 #include "XDRFileUnMarshaller.h"
 #include "XDRStreamUnMarshaller.h"
 #include "XDRStreamMarshaller.h"
+#if 0
 #include "DODSFilter.h"
+#endif
+#include "ResponseBuilder.h"
 #include "Response.h"
 #include "Connect.h"
 #include "Error.h"
@@ -505,29 +508,39 @@ constrained_trans(const string & dds_name, const bool constraint_expr,
     // versatility 02/05/07 jhrg
     set_series_values(server, series_values);
 
-    DODSFilter df;
+    ResponseBuilder df;
     df.set_ce(ce);
     df.set_dataset_name(dds_name);
-    df.set_URL("test://test");
-    df.set_response("DataDDS");
+    // df.set_URL("test://test");
+    // df.set_response("DataDDS");
 
     ofstream out("expr-test-data.bin", ios::out|ios::trunc|ios::binary);
+#if 0
     df.send_data(server, eval, out, "", false);
+#endif
+    df.send_data(out, server, eval, true);
+    //cout << "Server protocol version: " << server.get_dap_major() << "." << server.get_dap_minor() << endl;
     out.close();
 
     // Now do what Connect::request_data() does:
     FILE *fp = fopen("expr-test-data.bin", "r");
 
     Response r(fp, 400);
+#if 0
     r.set_type(dods_data);
     r.set_protocol("3.2");
-
+#endif
     Connect c("http://dummy_argument");
 
     BaseTypeFactory factory;
-    DataDDS dds(&factory, "Test_data", "DAP/3.1");      // Must use DataDDS on receiving end
+    DataDDS dds(&factory, "Test_data", "DAP/3.2");      // Must use DataDDS on receiving end
 
+#if 0
     c.read_data_no_mime(dds, &r);
+#endif
+    c.read_data(dds, &r);
+
+    //cout << "Protocol version: " << dds.get_protocol() << endl;
 
     cout << "The data:" << endl;
     for (DDS::Vars_iter q = dds.var_begin(); q != dds.var_end(); q++) {
