@@ -30,7 +30,22 @@
 
 #include "config.h"
 
-// #define DODS_DEBUG2
+//#define DODS_DEBUG2
+// #define DODS_DEBUG
+
+#include "Byte.h"
+#include "Int16.h"
+#include "UInt16.h"
+#include "Int32.h"
+#include "UInt32.h"
+#include "Float32.h"
+#include "Float64.h"
+#include "Str.h"
+#include "Url.h"
+#include "Array.h"
+#include "Structure.h"
+#include "Sequence.h"
+#include "Grid.h"
 
 #include "DDS.h"
 
@@ -81,257 +96,74 @@ class DDSTest: public TestFixture {
             return match == static_cast<int> (s.length());
         }
 
+        // The tests commented exercise features no longer supported
+        // by libdap. In particular, a DAS must now be properly structured
+        // to work with transfer_attributes() - if a handler builds a malformed
+        // DAS, it will need to specialize the BaseType::transfer_attributes()
+        // method.
         CPPUNIT_TEST_SUITE( DDSTest );
 #if 1
-        CPPUNIT_TEST(symbol_name_test);
-        CPPUNIT_TEST(print_xml_test);
-        CPPUNIT_TEST(find_hdf4_dimension_attribute_home_test);
-        CPPUNIT_TEST(find_matching_container_test);
-        CPPUNIT_TEST(transfer_attributes_test);
-        // These test both transfer_attributes() and print_xml()
-#endif
-        CPPUNIT_TEST(print_xml_test2);
-#if 1
-        CPPUNIT_TEST(print_xml_test3);
-        CPPUNIT_TEST(print_xml_test3_1);
-        CPPUNIT_TEST(print_xml_test4);
-        CPPUNIT_TEST(print_xml_test5);
-        CPPUNIT_TEST(print_xml_test5_1);
+        CPPUNIT_TEST(transfer_attributes_test_1);
+        CPPUNIT_TEST(transfer_attributes_test_2);
 
-        CPPUNIT_TEST(print_xml_test6);
-        CPPUNIT_TEST(print_xml_test7);
+        CPPUNIT_TEST(symbol_name_test);
+        // These test both transfer_attributes() and print_xml()
+        CPPUNIT_TEST(print_xml_test);
+        CPPUNIT_TEST(print_xml_test2);
+        CPPUNIT_TEST(print_xml_test3);
 #endif
-        //CPPUNIT_TEST(add_global_attribute_test);
+        // CPPUNIT_TEST(print_xml_test3_1);
+#if 1
+        CPPUNIT_TEST(print_xml_test4);
+
+        CPPUNIT_TEST(print_xml_test5);
+#endif
+        // CPPUNIT_TEST(print_xml_test5_1);
+#if 1
+        CPPUNIT_TEST(print_xml_test6);
+#endif
+        // CPPUNIT_TEST(print_xml_test7);
 
         CPPUNIT_TEST_SUITE_END();
 
-        void find_hdf4_dimension_attribute_home_test() {
-            try {
-                dds1->parse((string)TEST_SRC_DIR + "/dds-testsuite/3B42.980909.5.HDF.dds");
-                DAS das;
-                das.parse((string)TEST_SRC_DIR + "/dds-testsuite/3B42.980909.5.hacked.HDF.das");
-
-                AttrTable::Attr_iter eb = das.var_begin();
-                AttrTable::Attr_iter ei = eb + 2;
-                CPPUNIT_ASSERT((*ei)->name == "percipitate_dim_0");
-                BaseType *btp = dds1->find_hdf4_dimension_attribute_home(*ei);
-                CPPUNIT_ASSERT(btp->name() == "percipitate" && btp->is_vector_type());
-                ei = eb + 4;
-                btp = dds1->find_hdf4_dimension_attribute_home(*ei);
-                CPPUNIT_ASSERT(btp->name() == "percipitate" && btp->is_vector_type());
-
-                ei = eb + 1;
-                btp = dds1->find_hdf4_dimension_attribute_home(*ei);
-                CPPUNIT_ASSERT(!btp);
-
-                dds2->parse((string)TEST_SRC_DIR + "/dds-testsuite/hdf_dimension_attribute_grid.dds");
-                DAS das2;
-                das2.parse((string)TEST_SRC_DIR + "/dds-testsuite/hdf_dimension_attribute_grid.das");
-                eb = das2.var_begin();
-                ei = eb + 1;
-                CPPUNIT_ASSERT((*ei)->name == "g_dim_0");
-                btp = dds2->find_hdf4_dimension_attribute_home(*ei);
-                CPPUNIT_ASSERT(btp->name() == "x" && btp->is_vector_type());
-                CPPUNIT_ASSERT(btp->get_parent()->type() == dods_grid_c);
-
-                ei = eb + 2;
-                CPPUNIT_ASSERT((*ei)->name == "g_dim_1");
-                btp = dds2->find_hdf4_dimension_attribute_home(*ei);
-                CPPUNIT_ASSERT(btp->name() == "y" && btp->is_vector_type());
-                CPPUNIT_ASSERT(btp->get_parent()->type() == dods_grid_c);
-            }
-
-            catch (Error &e) {
-                cout << "Error: " << e.get_error_message() << endl;
-                CPPUNIT_FAIL("Error thrown!");
-            }
-        }
-
-        void find_matching_container_test() {
-            try {
-                dds1->parse((string)TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.dds");
-                DAS das;
-                das.parse((string)TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.das");
-
-                AttrTable::Attr_iter i = das.var_begin();
-                while (i != das.var_end()) {
-                    if ((*i)->type != Attr_container)
-                    continue;
-                    DBG(cerr << "looking for a destination for '" << (*i)->name
-                            << "'" << endl);
-                    BaseType *dest_var = 0;
-                    AttrTable *dest = dds1->find_matching_container((*i), &dest_var);
-                    BaseType *variable = dds1->var((*i)->name);
-                    AttrTable *matching = variable ? &variable->get_attr_table(): 0;
-                    if (variable) {
-                        DBG(cerr << "variable: " << variable->name() << endl);
-                        if (dest_var)
-                        DBG(cerr << "dest_var: " << dest_var->name() << endl);
-                        CPPUNIT_ASSERT(dest_var == variable);
-                        CPPUNIT_ASSERT(dest == matching);
-                    }
-                    else {
-                        CPPUNIT_ASSERT(dest_var == 0);
-                        CPPUNIT_ASSERT(dest != 0);
-                    }
-
-                    ++i;
-                }
-
-                dds2->parse((string)TEST_SRC_DIR + "/dds-testsuite/hdf_dimension_attribute_grid.dds");
-                DAS das2;
-                das2.parse((string)TEST_SRC_DIR + "/dds-testsuite/hdf_dimension_attribute_grid.das");
-
-                // There are three containers in the DAS and the _dim_0/1
-                // containers should be bound to the Grid's map vectors.
-                i = das2.var_begin();
-                DBG(cerr << "looking for a destination for '" << (*i)->name << "'"
-                        << endl);
-                BaseType *dest_var = 0;
-                AttrTable *dest = dds2->find_matching_container((*i), &dest_var);
-                Grid *g = dynamic_cast<Grid*>(dds2->var("g"));
-                CPPUNIT_ASSERT(g);
-                CPPUNIT_ASSERT(dest == &g->get_attr_table());
-
-                ++i;
-                DBG(cerr << "looking for a destination for '" << (*i)->name << "'"
-                        << endl);
-                dest = dds2->find_matching_container((*i), &dest_var);
-                Array *m = dynamic_cast<Array*>(*(g->map_begin()));
-                CPPUNIT_ASSERT(m);
-                CPPUNIT_ASSERT(dest == &m->get_attr_table());
-
-                ++i;
-                DBG(cerr << "looking for a destination for '" << (*i)->name << "'"
-                        << endl);
-                dest = dds2->find_matching_container((*i), &dest_var);
-                m = dynamic_cast<Array*>(*(g->map_begin()+1));
-                CPPUNIT_ASSERT(m);
-                CPPUNIT_ASSERT(dest == &m->get_attr_table());
-            }
-
-            catch (Error &e) {
-                cout << "Error: " << e.get_error_message() << endl;
-                CPPUNIT_FAIL("Error thrown!");
-            }
-        }
-
-        // This is here mostly to test for memory leaks using valgrind. Does
-        // DDS::add_global_attribute() leak memory? Apparently not. jhrg 3/18/05
-#if 0
-        void add_global_attribute_test() {
-            DAS das;
-            das.parse("./das-testsuite/test.1.das");
-            AttrTable::Attr_iter i = das.var_begin();
-            CPPUNIT_ASSERT(i != das.attr_end());
-
-            dds1->parse((string)TEST_SRC_DIR + "/dds-testsuite/test.1");
-            dds1->add_global_attribute(*i);
-
-            CPPUNIT_ASSERT(dds1->d_attr.get_size() == 1);
-        }
-#endif
-
-        void transfer_attributes_test() {
+        void transfer_attributes_test_1() {
             try {
                 dds1->parse((string)TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.dds");
                 DAS das;
                 das.parse((string)TEST_SRC_DIR + "/dds-testsuite/fnoc1.nc.das");
                 dds1->transfer_attributes(&das);
 
+                DBG2(dds1->print_xml(cerr, false, ""));
+
                 AttrTable &at = dds1->get_attr_table();
                 AttrTable::Attr_iter i = at.attr_begin();
-                CPPUNIT_ASSERT(at.get_name(i) == "NC_GLOBAL");
-                CPPUNIT_ASSERT(at.get_name(++i) == "DODS_EXTRA");
+                CPPUNIT_ASSERT(i != at.attr_end() && at.get_name(i) == "NC_GLOBAL");
+                CPPUNIT_ASSERT(i != at.attr_end() && at.get_name(++i) == "DODS_EXTRA");
             }
             catch (Error &e) {
                 cout << "Error: " << e.get_error_message() << endl;
                 CPPUNIT_FAIL("Error thrown!");
             }
+        }
 
+        void transfer_attributes_test_2() {
             try {
                 dds2->parse((string)TEST_SRC_DIR + "/dds-testsuite/3B42.980909.5.HDF.dds");
                 DAS das;
                 das.parse((string)TEST_SRC_DIR + "/dds-testsuite/3B42.980909.5.hacked.HDF.das");
                 dds2->transfer_attributes(&das);
 
+                DBG2(dds2->print_xml(cerr, false, ""));
+
                 AttrTable &at = dds2->get_attr_table();
                 AttrTable::Attr_iter i = at.attr_begin();
-                CPPUNIT_ASSERT(at.get_name(i) == "HDF_GLOBAL");
-                CPPUNIT_ASSERT(at.get_name(++i) == "CoreMetadata");
+                CPPUNIT_ASSERT(i != at.attr_end() && at.get_name(i) == "HDF_GLOBAL");
+                CPPUNIT_ASSERT(i != at.attr_end() && at.get_name(++i) == "CoreMetadata");
             }
             catch (Error &e) {
                 cout << "Error: " << e.get_error_message() << endl;
                 CPPUNIT_FAIL("Error thrown!");
             }
-
-            try {
-                BaseTypeFactory factory;
-                DDS dds(&factory);
-                dds.parse((string)TEST_SRC_DIR + "/dds-testsuite/S2000415.HDF.dds");
-                DAS das;
-                das.parse((string)TEST_SRC_DIR + "/dds-testsuite/S2000415.HDF.das");
-                dds.transfer_attributes(&das);
-
-                AttrTable &at = dds.get_attr_table();
-                AttrTable::Attr_iter i = at.attr_begin();
-                CPPUNIT_ASSERT(at.get_name(i) == "HDF_GLOBAL");
-                AttrTable &at2 = dds.var("WVC_Lat")->get_attr_table();
-                DBG2(at2.print(stderr));
-                CPPUNIT_ASSERT(at2.get_name(at2.attr_begin()) == "long_name");
-            }
-            catch (Error &e) {
-                cout << "Error: " << e.get_error_message() << endl;
-                CPPUNIT_ASSERT(!"Error thrown!");
-            }
-            try {
-                BaseTypeFactory factory;
-                DDS dds(&factory);
-                dds.parse((string)TEST_SRC_DIR + "/dds-testsuite/S2000415.HDF.dds");
-                DAS das;
-                das.parse((string)TEST_SRC_DIR + "/dds-testsuite/S2000415.HDF.test1.das");
-                dds.transfer_attributes(&das);
-
-                AttrTable &at2 = dds.var("WVC_Lat")->get_attr_table();
-                DBG2(at2.print(stderr));
-                CPPUNIT_ASSERT(at2.get_name(at2.attr_begin()) == "long_name");
-            }
-            catch (Error &e) {
-                cout << "Error: " << e.get_error_message() << endl;
-                CPPUNIT_FAIL("Error thrown!");
-            }
-#if 0
-            // This part of the test requires files written by Patrick that have
-            // not been checked into SVN as of 9/18/08 (it looks like the changes
-            // to DDSTest.cc were made on the multifile branch around 2/28/08.
-            // jhrg 9/18/08
-            try {
-                BaseTypeFactory factory;
-                DDS dds(&factory);
-                dds.parse((string)TEST_SRC_DIR + "/dds-testsuite/S2000415.fnoc1.dds");
-                DAS das;
-                das.parse((string)TEST_SRC_DIR + "/dds-testsuite/S2000415.fnoc1.das");
-                dds.container_name( "fnoc1" );
-                das.container_name( "fnoc1" );
-                dds.transfer_attributes(&das);
-                dds.container_name( "S2000415" );
-                das.container_name( "S2000415" );
-                dds.transfer_attributes(&das);
-
-                dds.print(cout);
-                das.print(cout);
-                BaseType *bt = dds.var("WVC_Lat");
-                CPPUNIT_ASSERT(bt);
-                AttrTable &at2 = bt->get_attr_table();
-                at2.print(cout);
-                DBG2(at2.print(stderr));
-                CPPUNIT_ASSERT(at2.get_name(at2.attr_begin()) == "long_name");
-            }
-            catch (Error &e) {
-                cout << "Error: " << e.get_error_message() << endl;
-                CPPUNIT_FAIL("Error thrown!");
-            }
-#endif
         }
 
         void symbol_name_test() {
@@ -355,10 +187,6 @@ class DDSTest: public TestFixture {
 
         void print_xml_test() {
             dds2->parse((string)TEST_SRC_DIR + "/dds-testsuite/test.19b");
-#if 0
-            char DDSTemp[] = {"/var/tmp/DDSTestXXXXXX"};
-            FILE *tmp = get_temp_file(DDSTemp);
-#endif
             ostringstream oss;
             dds2->print_xml(oss, false, "http://localhost/dods/test.xyz");
             Regex r("<.xml version=\"1.0\" encoding=\"UTF-8\".>\n\
@@ -384,10 +212,6 @@ class DDSTest: public TestFixture {
     <dataBLOB href=\"\"/>\n\
 </Dataset>\n");
             CPPUNIT_ASSERT(re_match(r, oss.str()));
-#if 0
-            fclose(tmp);
-            remove(DDSTemp);
-#endif
             }
 
         void print_xml_test2() {
@@ -457,6 +281,8 @@ class DDSTest: public TestFixture {
             CPPUNIT_ASSERT(re_match(r, oss.str()));
         }
 
+        // This tests the HDF4 <var>_dim_n attribute. support for that was
+        // moved to the handler itself.
         void print_xml_test3_1() {
             dds2->parse((string)TEST_SRC_DIR + "/dds-testsuite/test.19d");
             DAS das;
@@ -576,6 +402,8 @@ class DDSTest: public TestFixture {
             CPPUNIT_ASSERT(re_match(r, oss.str()));
         }
 
+        // Tests flat DAS into a DDS; no longer supported by libdap; specialize
+        // handlers if they make these malformed DAS objects
         void print_xml_test5_1() {
             dds2->parse((string)TEST_SRC_DIR + "/dds-testsuite/test.19f");
             DAS das;
@@ -698,6 +526,8 @@ class DDSTest: public TestFixture {
             CPPUNIT_ASSERT(re_match(r, oss.str()));
         }
 
+        // Tests flat DAS into a DDS; no longer supported by libdap; specialize
+        // handlers if they make these malformed DAS objects
         void print_xml_test7() {
             dds2->parse((string)TEST_SRC_DIR + "/dds-testsuite/test.19g");
             DAS das;
