@@ -54,6 +54,8 @@ using namespace libdap;
 
 int test_variable_sleep_interval = 0;
 
+namespace libdap {
+
 class DODSFilterTest : public TestFixture {
 private:
     DODSFilter *df, *df_conditional, *df1, *df2, *df3, *df4, *df5, *df6;
@@ -79,54 +81,52 @@ public:
     void setUp() {
 	// Test pathname
 	string test_file = (string)TEST_SRC_DIR + "/server-testsuite/bears.data" ;
-	char *argv_1[] = {"test_case", (char *)test_file.c_str()};
+	char *argv_1[] = {(char*)"test_case", (char *)test_file.c_str()};
 	df = new DODSFilter(2, argv_1);
 
-	char *argv_1_1[] = {"test_case", (char *)test_file.c_str(), "-l", &now_array[0]};
+	char *argv_1_1[] = {(char*)"test_case", (char *)test_file.c_str(), (char*)"-l", &now_array[0]};
 	df_conditional = new DODSFilter(4, argv_1_1);
 
 	// Test missing file
-	argv_1[1] = "no-such-file";
+	argv_1[1] = (char*)"no-such-file";
 	df1 = new DODSFilter(2, argv_1);
 
 	// Test files in CWD. Note that the time is the GM time : Tue, 01 May
 	// 2001 01:08:14 -0700
-	argv_1[1] = "test_config.h";
+	argv_1[1] = (char*)"test_config.h";
 	df2 = new DODSFilter(2, argv_1);
 
 	// This file has an ancillary DAS in the server-testsuite dir.
 	// df3 is also used to test escaping stuff in URLs. 5/4/2001 jhrg
 	char *argv_2[8];
-	argv_2[0] = "test_case";
+	argv_2[0] = (char*)"test_case";
 	test_file = (string)TEST_SRC_DIR + "/server-testsuite/coads.data";
 	argv_2[1] = (char *)test_file.c_str();
-	argv_2[2] = "-l";
+	argv_2[2] = (char*)"-l";
 	argv_2[3] = &now_array[0];
-	argv_2[4] = "-e";
-	argv_2[5] = "u,x,z[0]&grid(u,\"lat<10.0\")";
-	argv_2[6] = "-t";
-	argv_2[7] = "1";
+	argv_2[4] = (char*)"-e";
+	argv_2[5] = (char*)"u,x,z[0]&grid(u,\"lat<10.0\")";
+	argv_2[6] = (char*)"-t";
+	argv_2[7] = (char*)"1";
 	df3 = new DODSFilter(6, argv_2);
 
 	// Go back to this data source to test w/o an ancillary DAS.
-	argv_2[0] = "test_case";
+	argv_2[0] = (char*)"test_case";
 	test_file = (string)TEST_SRC_DIR + "/server-testsuite/bears.data";
 	argv_2[1] = (char *)test_file.c_str();
-	argv_2[2] = "-l";
+	argv_2[2] = (char*)"-l";
 	argv_2[3] = &now_array[0];
-	argv_2[4] = "-e";
-	argv_2[5] = "u,x,z[0]&grid(u,\"lat<10.0\")";
-	argv_2[6] = "-t";
-	argv_2[7] = "1";
+	argv_2[4] = (char*)"-e";
+	argv_2[5] = (char*)"u,x,z[0]&grid(u,\"lat<10.0\")";
+	argv_2[6] = (char*)"-t";
+	argv_2[7] = (char*)"1";
 	df4 = new DODSFilter(6, argv_2);
 
 	// Test escaping stuff. 5/4/2001 jhrg
-	char *argv_3[]={"test_case", "nowhere%5Bmydisk%5Dmyfile", "-e",
-			"u%5B0%5D"};
+	char *argv_3[]={(char*)"test_case", (char*)"nowhere%5Bmydisk%5Dmyfile", (char*)"-e", (char*)"u%5B0%5D"};
 	df5 = new DODSFilter(4, argv_3);
 
-	char *argv_4[]={"test_case", "nowhere%3a%5bmydisk%5dmyfile", "-e",
-			"Grid%20field%3au%5b0%5d,Grid%20field%3av"};
+	char *argv_4[]={(char*)"test_case", (char*)"nowhere%3a%5bmydisk%5dmyfile", (char*)"-e", (char*)"Grid%20field%3au%5b0%5d,Grid%20field%3av"};
 	df6 = new DODSFilter(4, argv_4);
 
 	cont_a = new AttrTable;
@@ -179,14 +179,46 @@ public:
 	DBG(cerr << "r.match(s): " << pos << endl);
 	return pos > 0;
     }
+
 #if 0
-    // Tests for methods
-    void read_ancillary_das_test() {
+    void add_keyword_test() {
+	DODSFilter tdf;
+	tdf.add_keyword("test");
+	CPPUNIT_ASSERT(tdf.d_keywords.find("test") != tdf.d_keywords.end());
+	CPPUNIT_ASSERT(tdf.d_keywords.find("test") == tdf.d_keywords.begin());
+	CPPUNIT_ASSERT(*(tdf.d_keywords.find("test")) == string("test"));
+	tdf.add_keyword("dap3.3");
+	CPPUNIT_ASSERT(tdf.d_keywords.size() == 2);
     }
 
-    void read_ancillary_dds_test() {
+    void is_keyword_test() {
+	DODSFilter tdf;
+	tdf.add_keyword("test");
+	tdf.add_keyword("dap3.3");
+	CPPUNIT_ASSERT(tdf.is_keyword("test"));
+	CPPUNIT_ASSERT(!tdf.is_keyword("TEST"));
+    }
+
+    void get_keywords() {
+	DODSFilter tdf;
+	tdf.add_keyword("test");
+	tdf.add_keyword("dap2.0");
+	tdf.add_keyword("dap4.0");
+	CPPUNIT_ASSERT(tdf.d_keywords.size() == 3);
+
+	ostringstream oss;
+	list<string> kwds = tdf.get_keywords();
+	list<string>::iterator i = kwds.begin();
+	while (i != kwds.end())
+	    oss << *i++;
+	//cerr << oss.str() << endl;
+
+	CPPUNIT_ASSERT(oss.str().find("test") != string::npos);
+	CPPUNIT_ASSERT(oss.str().find("dap2.0") != string::npos);
+	CPPUNIT_ASSERT(oss.str().find("dap4.0") != string::npos);
     }
 #endif
+
     void get_dataset_last_modified_time_test() {
 	time_t t = time(0);
 	CPPUNIT_ASSERT(df1->get_dataset_last_modified_time() == t);
@@ -498,25 +530,31 @@ Content-Encoding: binary\r\n\
     }
 
     CPPUNIT_TEST_SUITE( DODSFilterTest );
-#if 1
+#if 0
+    CPPUNIT_TEST(add_keyword_test);
+    CPPUNIT_TEST(is_keyword_test);
+    CPPUNIT_TEST(get_keywords);
+#endif
+
     CPPUNIT_TEST(get_dataset_last_modified_time_test);
     CPPUNIT_TEST(get_das_last_modified_time_test);
 
     CPPUNIT_TEST(send_das_test);
     CPPUNIT_TEST(send_dds_test);
-#endif
+
     CPPUNIT_TEST(send_ddx_test);
     CPPUNIT_TEST(send_data_ddx_test);
     CPPUNIT_TEST(send_data_ddx_test2);
-#if 1
+
     CPPUNIT_TEST(is_conditional_test);
     CPPUNIT_TEST(get_request_if_modified_since_test);
     CPPUNIT_TEST(escape_code_test);
-#endif
+
     CPPUNIT_TEST_SUITE_END();
 };
 
 CPPUNIT_TEST_SUITE_REGISTRATION(DODSFilterTest);
+}
 
 int
 main( int, char** )
