@@ -30,7 +30,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: util_mit.cc 21214 2009-08-04 16:15:54Z jimg $"
+    {"$Id: util_mit.cc 24370 2011-03-28 16:21:32Z jimg $"
     };
 
 #include <cstdio>
@@ -317,7 +317,7 @@ string date_time_str(time_t *calendar, bool local)
 #if defined(_REENTRANT)
         struct tm loctime;
         localtime_r(calendar, &loctime);
-        sprintf(buf, "%s, %02d %s %04d %02d:%02d:%02d",
+        snprintf(buf, 40, "%s, %02d %s %04d %02d:%02d:%02d",
                 wkdays[loctime.tm_wday],
                 loctime.tm_mday,
                 months[loctime.tm_mon],
@@ -327,7 +327,7 @@ string date_time_str(time_t *calendar, bool local)
                 loctime.tm_sec);
 #else
     struct tm *loctime = localtime(calendar);
-    sprintf(buf, "%s, %02d %s %04d %02d:%02d:%02d",
+    snprintf(buf, 40, "%s, %02d %s %04d %02d:%02d:%02d",
             wkdays[loctime->tm_wday],
             loctime->tm_mday,
             months[loctime->tm_mon],
@@ -341,7 +341,7 @@ string date_time_str(time_t *calendar, bool local)
 #if defined(_REENTRANT) || defined(SOLARIS)
         struct tm gmt;
         gmtime_r(calendar, &gmt);
-        sprintf(buf, "%s, %02d %s %04d %02d:%02d:%02d GMT",
+        snprintf(buf, 40, "%s, %02d %s %04d %02d:%02d:%02d GMT",
                 wkdays[gmt.tm_wday],
                 gmt.tm_mday,
                 months[gmt.tm_mon],
@@ -351,7 +351,7 @@ string date_time_str(time_t *calendar, bool local)
                 gmt.tm_sec);
 #else
     struct tm *gmt = gmtime(calendar);
-    sprintf(buf, "%s, %02d %s %04d %02d:%02d:%02d GMT",
+    snprintf(buf, 40, "%s, %02d %s %04d %02d:%02d:%02d GMT",
             wkdays[gmt->tm_wday],
             gmt->tm_mday,
             months[gmt->tm_mon],
